clear all

% Costanti fisiche
global g = 9.81;
global rho = 1e3;
global mu = 1e-3;
global L = 30;
global es = 0.001;
global k = 0.5; % Imbocco
global z1 = 1;
global D = 0.10;
global h1 = 4;

global r = 0.4; % Raggio della cisterna

function z = bernoulli(Q)
	global g;
	global rho;
	global mu;
	global L;
	global es;
	global k;
	global z1;
	global D;
	global h1;

	% Calcolo la velocità
	v = hspeed(Q, D);
	% Calcolo il carico totale
	H12 = z1 + h1 - v.^2/(2.*g);
	% Calcolo la viscosità cinematica
	nu = mu ./ rho;
	% Calcolo il numero di Reynolds
	Re = Reynolds(v, D, nu);
	% Calcolo il coefficiente di attrito
	f = churchill(Re, es ./ D);
	% Calcolo le perdite di carico distribuite
	WD = loss_l(f, D, L, v, g);
	% Calcolo le perdite di carico concentrate
	WC = loss_k(k, v, g);
	% Calcolo il valore della funzione
	z = H12 - WD - WC;
end

Q = fsolve(@bernoulli, 0.001) % Stima iniziale: 1L/sec